@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.038'; # VERSION
+our $VERSION = '0.039'; # VERSION
 
 use Mouse;
 use Carp;
@@ -54,6 +54,7 @@ has def => (is => 'ro', isa => 'Str');
 has namespace => (is => 'ro', isa => 'Str');
 has comment => (is => 'ro', isa => 'Str');
 has alt_id => (is => 'ro', isa => 'ArrayRef');
+has xref => (is => 'ro', isa => 'ArrayRef');
 has subset => (is => 'ro', isa => 'ArrayRef');
 has is_relationshiptype => (is => 'ro', isa => 'Bool');
 has is_obsolete => (is => 'ro', isa => 'Bool');
@@ -127,6 +128,13 @@ sub subsets
   return @{$self->{subset} // []};
 }
 
+sub xrefs
+{
+  my $self = shift;
+
+  return @{$self->{xref} // []};
+}
+
 =head2 make_object
 
  Usage   : my $object = PomBase::Chobo::OntologyTerm->make_object($args);
